package qiniu.titan_plugin;

import android.app.Application;
import android.content.Context;

import java.util.ArrayList;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import vip.z4k.android.sdk.TitanSDK;

/** TitanPlugin */
public class TitanPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private static volatile Context ctx;

  @Override
  public void onAttachedToEngine(FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "titan_plugin");
    channel.setMethodCallHandler(this);
    ctx = flutterPluginBinding.getApplicationContext();
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "titan_plugin");
    channel.setMethodCallHandler(new TitanPlugin());
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("start")) {
      System.out.println("app" + ctx);
      TitanSDK.start(ctx);
      result.success(null);
    } else if (call.method.equals("stop")) {
      TitanSDK.stop();
      result.success(null);
    } else if (call.method.equals("setToken")) {
      ArrayList<Integer> s = call.arguments();
      Integer i = s.get(0);
      TitanSDK.setToken(i);
      result.success(null);
    } else if (call.method.equals("setPauseTimeout")) {
      ArrayList<Integer> s = call.arguments();
      Integer i = s.get(0);
      TitanSDK.setPauseTimeout(i);
      result.success(null);
    } else if (call.method.equals("setSleepTimeout")) {
      ArrayList<Integer> s = call.arguments();
      Integer i = s.get(0);
      TitanSDK.setSleepTimeout(i);
      result.success(null);
    } else if (call.method.equals("addHttpHeaderBypassKey")) {
      ArrayList<String> s = call.arguments();
      String i = s.get(0);
      TitanSDK.addHttpHeaderBypassKey(i);
      result.success(null);
    } else if (call.method.equals("getVodUrl")) {
      ArrayList<String> s = call.arguments();
      String i = s.get(0);
      String j = s.get(1);
      String r = TitanSDK.getVodUrl(i, j);
      result.success(r);
    } else if (call.method.equals("getDownloadUrl")) {
      ArrayList<String> s = call.arguments();
      String i = s.get(0);
      String j = s.get(1);
      String r = TitanSDK.getDownloadUrl(i, j);
      result.success(r);
    } else{
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}
